@@ -31,12 +31,21 @@ class ILavaServerExtension(object):
     __metaclass__ = ABCMeta
 
     @abstractmethod
-    def contribute_to_settings(self, settings):
+    def contribute_to_settings(self, settings_module):
         """
         Add elements required to initialize this extension into the project
         settings module.
         """
 
+    @abstractmethod
+    def contribute_to_settings_ex(self, settings_module, settings_object):
+        """
+        This method is similar to contribute_to_settings() but allows
+        implementation to access a settings object from django-debian. This
+        allows extensions to read settings provided by local system
+        administrator.
+        """
+
     @abstractmethod
     def contribute_to_urlpatterns(self, urlpatterns):
         """
@@ -65,6 +74,12 @@ class ILavaServerExtension(object):
         Version of this extension.
         """
 
+    @abstractproperty
+    def front_page_template(self):
+        """
+        Name of the front page template to {% include %}, may be None
+        """
+
     @abstractmethod
     def get_main_url(self):
         """
@@ -94,6 +109,10 @@ class LavaServerExtension(ILavaServerExtension):
         Name of the main view
         """
 
+    @property
+    def front_page_template(self):
+        return None
+
     @property
     def api_class(self):
         """
@@ -103,9 +122,12 @@ class LavaServerExtension(ILavaServerExtension):
         """
         return None
 
-    def contribute_to_settings(self, settings):
-        settings['INSTALLED_APPS'].append(self.app_name)
-        settings['PREPEND_LABEL_APPS'].append(self.app_name)
+    def contribute_to_settings(self, settings_module):
+        settings_module['INSTALLED_APPS'].append(self.app_name)
+        settings_module['STATICFILES_PREPEND_LABEL_APPS'].append(self.app_name)
+
+    def contribute_to_settings_ex(self, settings_module, settings_object):
+        pass
 
     def contribute_to_urlpatterns(self, urlpatterns):
         from django.conf.urls.defaults import url, include 
@@ -160,8 +182,31 @@ class ExtensionLoader(object):
         """
         List of extensions
         """
+
+        class ExtensionMapping(object):
+            """
+            Class that exposes extensions by application name
+            """
+
+            def __init__(self, extension_list):
+                self._extension_list = extension_list
+
+            def __getattr__(self, attr):
+                for extension in self._extension_list:
+                    if extension.app_name == attr:
+                        return extension
+
+        class ExtensionList(list):
+            """
+            List with an additional property, useful for Django views
+            """
+
+            @property
+            def as_mapping(self):
+                return ExtensionMapping(self)
+
         if self._extensions is None:
-            self._extensions = []
+            self._extensions = ExtensionList()
             for name in self._find_extensions():
                 try:
                     extension = self._load_extension(name)
@@ -171,14 +216,18 @@ class ExtensionLoader(object):
                     self._extensions.append(extension)
         return self._extensions
 
-    def contribute_to_settings(self, settings):
+    def contribute_to_settings(self, settings_module, settings_object=None):
         """
         Contribute to lava-server settings module.
 
-        The settings argument is a magic dictionary returned by locals()
+        The settings_object is optional (it may be None) and allows extensions
+        to look at the django-debian settings object. The settings_module
+        argument is a magic dictionary returned by locals()
         """
         for extension in self.extensions:
-            extension.contribute_to_settings(settings)
+            extension.contribute_to_settings(settings_module)
+            if settings_object is not None:
+                extension.contribute_to_settings_ex(settings_module, settings_object)
 
     def contribute_to_urlpatterns(self, urlpatterns):
         """
